@@ -1,6 +1,6 @@
 #  This file is part of PyBuilder
 #
-#  Copyright 2011-2013 PyBuilder Team
+#  Copyright 2011-2014 PyBuilder Team
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -41,7 +41,7 @@ if __name__ == '__main__':
     setup(
           name = '$name',
           version = '$version',
-          description = '$summary',
+          description = '''$summary''',
           long_description = '''$description''',
           author = "$author",
           author_email = "$author_email",
